==> calendar-v1.7.21.zip: calendar/messages/pl/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Dodaj</strong> kalendarz profilowy',
    '<strong>Choose</strong> target calendar' => '<strong>Wybierz</strong> docelowy kalendarz',
    '<strong>Reminder</strong> settings' => 'Ustawienia <strong>przypomnień</strong>',
    'Add all Space members with status {status}' => 'Wszyscy użytkownicy strefy ze statusem {status}',
    'Add participants...' => 'Dodaj uczestników...',
    'Added: {users}' => 'Dodano: {users}',
    'Additional Information for participants' => 'Dodatkowa informacja dla uczestników',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Dodaje kalendarz dla wydarzeń prywatnych lub publicznych do twojego profilu i głównego menu.',
    'Adds an event calendar to this space.' => 'Dodaje kalendarz wydarzeń do tej strefy.',
    'After (occurrences)' => 'Po (occurrences)',
    'All Day' => 'Wszystkie dni',
    'Allow option \'Decline\'' => 'Zezwól na opcję \'Odmawiam\'',
    'Allow option \'Undecided\'' => 'Zezwól na opcję \'Niezdecydowany\'',
    'Allows the user to create new calendar entries' => 'Pozwala użytkownikom tworzyć nowe pozycje w kalendarzu',
    'Allows the user to edit/delete existing calendar entries' => 'Pozwala użytkownikom edytować/usuwać istniejące pozycje w kalendarzu',
    'Attending' => 'Biorę udział',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => 'Przed wybraniem kalendarza docelowego moduł musi być aktywowany w co najmniej jednej strefie.',
    'Birthday' => 'Urodziny',
    'CalDAV' => 'CalDAV',
    'Calendar' => 'Kalendarz',
    'Calendar event' => 'Wydarzenie kalendarza',
    'Calendar events' => 'Wydarzenia kalendarza',
    'Cancel Event' => 'Anuluj wydarzenie',
    'Cannot remove the participant!' => 'Nie można usunąć uczestnika!',
    'Create entry' => 'Tworzenie pozycji',
    'Custom reminder' => 'Własne przypomnienie',
    'Day' => 'Dzień',
    'Days' => 'Dni',
    'Default reminder settings' => 'Domyślne ustawienia przypomnień',
    'Delete all events' => 'Usuń wszystkie wydarzenia',
    'Deleted' => 'Usunięte',
    'Description' => 'Opis',
    'Display events within the next X days' => 'Wyświetl wydarzenia z kolejnych X dni',
    'Do you want to install this module on your profile?' => 'Czy chcesz zainstalować ten moduł na swoim profilu?',
    'Download ICS' => 'Pobierz ICS',
    'Edit' => 'Edytuj',
    'Edit Event' => 'Zmień wydarzenie',
    'Edit all events' => 'Edytuj wszystkie wydarzenia',
    'Edit this and following events' => 'Edytuj to i kolejne wydarzenia',
    'Edit this event' => 'Edytuj to wydarzenie',
    'Email' => 'E-mail',
    'Enable' => 'Włącz',
    'Enable Reminder' => 'Włącz przypomnienie',
    'End' => 'Koniec',
    'End Date' => 'Data zakończenia',
    'End Time' => 'Koniec',
    'End time must be after start time!' => 'Data zakończenia musi być po dacie początku!',
    'Event' => 'Wydarzenie',
    'Event Type' => 'Typ wydarzenia',
    'Event Types' => 'Typy wydarzeń',
    'Event could not be deleted!' => 'Wydarzenie nie może zostać skasowane!',
    'Event has been be deleted!' => 'Wydarzenie zostało skasowane!',
    'Event not found!' => 'Nie znaleziono wydarzenia!',
    'Export as {type}' => 'Eksportuj jako {type}',
    'Files' => 'Pliki',
    'Filter by types' => 'Filtruj wg typu',
    'Friday' => 'Piątek',
    'From Newest to Oldest' => 'Od najnowszych do najstarszych',
    'From Oldest to Newest' => 'Od najstarszych do najnowszych',
    'Here you can configure default settings for all calendar events.' => 'Tutaj możesz dostosować domyślne ustawienia dla wszystkich wydarzeń.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Tutaj możesz ustawić globalne domyślne przypomnienia. Te ustawienia mogą zostać zastąpione na poziomie strefy/profilu.',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
        <strong>Set reminder</strong> link.' => 'Tutaj możesz ustawić domyślne ustawienia przypomnień dla tego wydarzenia. Użytkownicy mogą nadpisać te ustawienia przez odnośnik  <strong>Ustaw przypomnienie</strong>.',
    'Hour' => 'Godzina',
    'I\'m attending' => 'Biorę udział',
    'ID' => 'Identyfikator',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Aby dodać wydarzenia do Twojego profilu, musisz najpierw uruchomić moduł kalendarza.',
    'Include Organizer and Participant Info in Exports' => 'Załącz dane organizatora i uczestnika przy eksporcie',
    'Interested' => 'Zainteresowany',
    'Invalid date or time format!' => 'Błędny format daty lub czasu!',
    'Invalid day of month given' => 'Podano nieprawidłowy dzień miesiąca',
    'Invalid event type id selected.' => 'Wybrano niepoprawne ID typu wydarzenia.',
    'Invalid frequency given' => 'Podano nieprawidłową częstotliwość',
    'Invalid interval given' => 'Podano nieprawidłowy odstęp',
    'Invalid week day selection' => 'Nieprawidłowy wybór dnia tygodnia',
    'Invite' => 'Zaproś',
    'Invited: {users}' => 'Zaproszeni: {users}',
    'JWT Key' => 'Klucz JWT',
    'JWT Token Expiration' => 'Wygaśnięcie tokena JWT',
    'List' => 'Lista',
    'Location' => 'Miejsce',
    'Manage entries' => 'Zarządzanie pozycjami',
    'Maximum number of participants' => 'Maksymalna liczba uczestników',
    'Minute' => 'Minuta',
    'Mode' => 'Tryb',
    'Monday' => 'Poniedziałek',
    'Month' => 'Miesiąc',
    'Monthly on day {dayOfMonth}' => 'Co miesiąc w dniu {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Co miesiąc w {position} {dayOfWeek}',
    'Months' => 'Miesięcy',
    'Never' => 'Nigdy',
    'Next' => 'Następny',
    'No new participants were added.' => 'Nie dodano nowych uczestników.',
    'No new participants were invited.' => 'Nie zaproszono nowych uczestników.',
    'No reminder' => 'Brak przypomnienia',
    'Notify participants about changes' => 'Powiadom uczestników o zmianach',
    'On date' => 'W dniu',
    'Participant removed.' => 'Uczestnicy usunięci.',
    'Participants' => 'Uczestnicy',
    'Participation Status' => 'Status uczestnictwa',
    'Please select new participants.' => 'Proszę wybierz nowych uczestników.',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => 'Wydarzenia prywatne są widoczne tylko dla Ciebie i, jeśli system znajomości jest włączony, dla Twoich znajomych.',
    'Profile Calendar' => 'Kalendarz profilowy',
    'Public' => 'Publiczny',
    'Recurring' => 'Powtarzające się',
    'Reopen Event' => 'Ponownie otwórz wydarzenie',
    'Repeat every' => 'Powtarzaj w każdy',
    'Saturday' => 'Sobota',
    'Select calendar...' => 'Wybierz kalendarz...',
    'Select space...' => 'Wybierz strefę...',
    'Set reminder' => 'Ustaw przypomnienie',
    'Show past events' => 'Pokaż dawne wydarzenia',
    'Sorting' => 'Sortowanie',
    'Start Date' => 'Data początku',
    'Start Time' => 'Początek',
    'Status cannot be updated.' => 'Status nie może zostać zaktualizowany.',
    'Status updated.' => 'Zaktualizowano status.',
    'Sunday' => 'Niedziela',
    'The event has already ended.' => 'Wydarzenie już się skończyło.',
    'This event does not support recurrent events' => 'To wydarzenie nie obsługuje powtarzanych zdarzeń',
    'Thursday' => 'Czwartek',
    'Time Zone' => 'Strefa czasowa',
    'Title' => 'Tytuł',
    'Today' => 'Dziś',
    'Tuesday' => 'Wtorek',
    'Upcoming {type}' => 'Nadchodzące {type}',
    'Upcoming {type}: {title}' => 'Nadchodzące {type}: {title}',
    'Use default reminder' => 'Użyj domyślnego przypomnienia',
    'User birthdays' => 'Urodziny użytownika',
    'Wednesday' => 'Środa',
    'Week' => 'Tydzień',
    'Weeks' => 'Tygodnie',
    'Year' => 'Rok',
    'Years' => 'Lata',
    'You cannot invite participants!' => 'Nie możesz zaprosić uczestników!',
    'You don\'t have permission to delete this event!' => 'Nie masz uprawnień aby usunąć to wydarzenie!',
    'You have an <strong>{type}</strong> coming up' => 'Posiadasz zbliżające się <strong>{type}</strong>',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Posiadasz zbliżające się <strong>{type}</strong>: {title}',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => 'Zapisałeś się na wydarzenie "{contentTitle}" w {spaceName}, ruszające o {time}',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => 'Przyjęto rejestrację na wydarzenie "{contentTitle}", ruszające o {time}.',
    'You have been registered for the event "{contentTitle}".' => 'Zapisałeś się na wydarzenie "{contentTitle}".',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Twoje ustawienie przypomnienia dla wydarzenia: <strong>\'{title}\'</strong>',
    'canceled' => 'anulowano',
    'disabled' => 'wyłączony',
    'first' => 'pierwszy',
    'forth' => 'czwarty',
    'global' => 'globalne',
    'iCal' => 'iCal',
    'last' => 'ostatnie',
    'on weekdays' => 'w dni tygodnia',
    'second' => 'sekund',
    'third' => 'trzecia',
    '{displayName} Birthday' => 'Urodziny {displayName}',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} właśnie dodał(a) Cię do wydarzenia "{contentTitle} w strefie {spaceName}, które startuje o {time}',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} dodał/a Cię do wydarzenia "{contentTitle}".',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} zaprosił cię do wzięcia udziału w "{contentTitle}" w strefie {spaceName}, rusza o {time}.',
    '{displayName} invited you to the event "{contentTitle}".' => '{displayName} zaprosił cię na wydarzenie "{contentTitle}".',
    '{name} Calendar' => '{name} kalendarza',
    'Calendar event content ID' => '',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
];

==> calendar-v1.8.3.zip: calendar/messages/pl/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Dodaj</strong> kalendarz profilowy',
    '<strong>Choose</strong> target calendar' => '<strong>Wybierz</strong> docelowy kalendarz',
    '<strong>Reminder</strong> settings' => 'Ustawienia <strong>przypomnień</strong>',
    'Add all Space members with status {status}' => 'Wszyscy użytkownicy strefy ze statusem {status}',
    'Add participants...' => 'Dodaj uczestników...',
    'Added: {users}' => 'Dodano: {users}',
    'Additional Information for participants' => 'Dodatkowa informacja dla uczestników',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Dodaje kalendarz dla wydarzeń prywatnych lub publicznych do twojego profilu i głównego menu.',
    'Adds an event calendar to this space.' => 'Dodaje kalendarz wydarzeń do tej strefy.',
    'After (occurrences)' => 'Po (occurrences)',
    'All Day' => 'Wszystkie dni',
    'Allow option \'Decline\'' => 'Zezwól na opcję \'Odmawiam\'',
    'Allow option \'Undecided\'' => 'Zezwól na opcję \'Niezdecydowany\'',
    'Allows the user to create new calendar entries' => 'Pozwala użytkownikom tworzyć nowe pozycje w kalendarzu',
    'Allows the user to edit/delete existing calendar entries' => 'Pozwala użytkownikom edytować/usuwać istniejące pozycje w kalendarzu',
    'Attending' => 'Biorę udział',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => 'Przed wybraniem kalendarza docelowego moduł musi być aktywowany w co najmniej jednej strefie.',
    'Birthday' => 'Urodziny',
    'CalDAV' => 'CalDAV',
    'Calendar' => 'Kalendarz',
    'Calendar event' => 'Wydarzenie kalendarza',
    'Calendar events' => 'Wydarzenia kalendarza',
    'Cancel Event' => 'Anuluj wydarzenie',
    'Cannot remove the participant!' => 'Nie można usunąć uczestnika!',
    'Create entry' => 'Tworzenie pozycji',
    'Custom reminder' => 'Własne przypomnienie',
    'Day' => 'Dzień',
    'Days' => 'Dni',
    'Default reminder settings' => 'Domyślne ustawienia przypomnień',
    'Delete all events' => 'Usuń wszystkie wydarzenia',
    'Deleted' => 'Usunięte',
    'Description' => 'Opis',
    'Display events within the next X days' => 'Wyświetl wydarzenia z kolejnych X dni',
    'Do you want to install this module on your profile?' => 'Czy chcesz zainstalować ten moduł na swoim profilu?',
    'Download ICS' => 'Pobierz ICS',
    'Edit' => 'Edytuj',
    'Edit Event' => 'Zmień wydarzenie',
    'Edit all events' => 'Edytuj wszystkie wydarzenia',
    'Edit this and following events' => 'Edytuj to i kolejne wydarzenia',
    'Edit this event' => 'Edytuj to wydarzenie',
    'Email' => 'E-mail',
    'Enable' => 'Włącz',
    'Enable Reminder' => 'Włącz przypomnienie',
    'End' => 'Koniec',
    'End Date' => 'Data zakończenia',
    'End Time' => 'Koniec',
    'End time must be after start time!' => 'Data zakończenia musi być po dacie początku!',
    'Event' => 'Wydarzenie',
    'Event Type' => 'Typ wydarzenia',
    'Event Types' => 'Typy wydarzeń',
    'Event could not be deleted!' => 'Wydarzenie nie może zostać skasowane!',
    'Event has been be deleted!' => 'Wydarzenie zostało skasowane!',
    'Event not found!' => 'Nie znaleziono wydarzenia!',
    'Export as {type}' => 'Eksportuj jako {type}',
    'Files' => 'Pliki',
    'Filter by types' => 'Filtruj wg typu',
    'Friday' => 'Piątek',
    'From Newest to Oldest' => 'Od najnowszych do najstarszych',
    'From Oldest to Newest' => 'Od najstarszych do najnowszych',
    'Here you can configure default settings for all calendar events.' => 'Tutaj możesz dostosować domyślne ustawienia dla wszystkich wydarzeń.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Tutaj możesz ustawić globalne domyślne przypomnienia. Te ustawienia mogą zostać zastąpione na poziomie strefy/profilu.',
    'Hour' => 'Godzina',
    'I\'m attending' => 'Biorę udział',
    'ID' => 'Identyfikator',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Aby dodać wydarzenia do Twojego profilu, musisz najpierw uruchomić moduł kalendarza.',
    'Include Organizer and Participant Info in Exports' => 'Załącz dane organizatora i uczestnika przy eksporcie',
    'Interested' => 'Zainteresowany',
    'Invalid date or time format!' => 'Błędny format daty lub czasu!',
    'Invalid day of month given' => 'Podano nieprawidłowy dzień miesiąca',
    'Invalid event type id selected.' => 'Wybrano niepoprawne ID typu wydarzenia.',
    'Invalid frequency given' => 'Podano nieprawidłową częstotliwość',
    'Invalid interval given' => 'Podano nieprawidłowy odstęp',
    'Invalid week day selection' => 'Nieprawidłowy wybór dnia tygodnia',
    'Invite' => 'Zaproś',
    'Invited: {users}' => 'Zaproszeni: {users}',
    'JWT Key' => 'Klucz JWT',
    'JWT Token Expiration' => 'Wygaśnięcie tokena JWT',
    'List' => 'Lista',
    'Location' => 'Miejsce',
    'Manage entries' => 'Zarządzanie pozycjami',
    'Maximum number of participants' => 'Maksymalna liczba uczestników',
    'Minute' => 'Minuta',
    'Mode' => 'Tryb',
    'Monday' => 'Poniedziałek',
    'Month' => 'Miesiąc',
    'Monthly on day {dayOfMonth}' => 'Co miesiąc w dniu {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Co miesiąc w {position} {dayOfWeek}',
    'Months' => 'Miesięcy',
    'Never' => 'Nigdy',
    'Next' => 'Następny',
    'No new participants were added.' => 'Nie dodano nowych uczestników.',
    'No new participants were invited.' => 'Nie zaproszono nowych uczestników.',
    'No reminder' => 'Brak przypomnienia',
    'Notify participants about changes' => 'Powiadom uczestników o zmianach',
    'On date' => 'W dniu',
    'Participant removed.' => 'Uczestnicy usunięci.',
    'Participants' => 'Uczestnicy',
    'Participation Status' => 'Status uczestnictwa',
    'Please select new participants.' => 'Proszę wybierz nowych uczestników.',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => 'Wydarzenia prywatne są widoczne tylko dla Ciebie i, jeśli system znajomości jest włączony, dla Twoich znajomych.',
    'Profile Calendar' => 'Kalendarz profilowy',
    'Public' => 'Publiczny',
    'Recurring' => 'Powtarzające się',
    'Reopen Event' => 'Ponownie otwórz wydarzenie',
    'Repeat every' => 'Powtarzaj w każdy',
    'Saturday' => 'Sobota',
    'Select calendar...' => 'Wybierz kalendarz...',
    'Select space...' => 'Wybierz strefę...',
    'Set reminder' => 'Ustaw przypomnienie',
    'Show past events' => 'Pokaż dawne wydarzenia',
    'Sorting' => 'Sortowanie',
    'Start Date' => 'Data początku',
    'Start Time' => 'Początek',
    'Status cannot be updated.' => 'Status nie może zostać zaktualizowany.',
    'Status updated.' => 'Zaktualizowano status.',
    'Sunday' => 'Niedziela',
    'The event has already ended.' => 'Wydarzenie już się skończyło.',
    'This event does not support recurrent events' => 'To wydarzenie nie obsługuje powtarzanych zdarzeń',
    'Thursday' => 'Czwartek',
    'Time Zone' => 'Strefa czasowa',
    'Title' => 'Tytuł',
    'Today' => 'Dziś',
    'Tuesday' => 'Wtorek',
    'Upcoming {type}' => 'Nadchodzące {type}',
    'Upcoming {type}: {title}' => 'Nadchodzące {type}: {title}',
    'Use default reminder' => 'Użyj domyślnego przypomnienia',
    'User birthdays' => 'Urodziny użytownika',
    'Wednesday' => 'Środa',
    'Week' => 'Tydzień',
    'Weeks' => 'Tygodnie',
    'Year' => 'Rok',
    'Years' => 'Lata',
    'You cannot invite participants!' => 'Nie możesz zaprosić uczestników!',
    'You don\'t have permission to delete this event!' => 'Nie masz uprawnień aby usunąć to wydarzenie!',
    'You have an <strong>{type}</strong> coming up' => 'Posiadasz zbliżające się <strong>{type}</strong>',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Posiadasz zbliżające się <strong>{type}</strong>: {title}',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => 'Zapisałeś się na wydarzenie "{contentTitle}" w {spaceName}, ruszające o {time}',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => 'Przyjęto rejestrację na wydarzenie "{contentTitle}", ruszające o {time}.',
    'You have been registered for the event "{contentTitle}".' => 'Zapisałeś się na wydarzenie "{contentTitle}".',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Twoje ustawienie przypomnienia dla wydarzenia: <strong>\'{title}\'</strong>',
    'canceled' => 'anulowano',
    'disabled' => 'wyłączony',
    'first' => 'pierwszy',
    'forth' => 'czwarty',
    'global' => 'globalne',
    'iCal' => 'iCal',
    'last' => 'ostatnie',
    'on weekdays' => 'w dni tygodnia',
    'second' => 'sekund',
    'third' => 'trzecia',
    '{displayName} Birthday' => 'Urodziny {displayName}',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} właśnie dodał(a) Cię do wydarzenia "{contentTitle} w strefie {spaceName}, które startuje o {time}',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} dodał/a Cię do wydarzenia "{contentTitle}".',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} zaprosił cię do wzięcia udziału w "{contentTitle}" w strefie {spaceName}, rusza o {time}.',
    '{displayName} invited you to the event "{contentTitle}".' => '{displayName} zaprosił cię na wydarzenie "{contentTitle}".',
    '{name} Calendar' => '{name} kalendarza',
    'Calendar event content ID' => '',
    'Filter' => '',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
    <strong>Set reminder</strong> link.' => '',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
];
